| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gst.Objects.ParamArray
Description
No description available in the introspection data.
Synopsis
- newtype ParamArray = ParamArray (ManagedPtr ParamArray)
- class (BoxedPtr o, TypedObject o, IsDescendantOf ParamArray o) => IsParamArray o
- toParamArray :: (MonadIO m, IsParamArray o) => o -> m ParamArray
Exported types
newtype ParamArray Source #
Memory-managed wrapper type.
Constructors
| ParamArray (ManagedPtr ParamArray) |
Instances
| Eq ParamArray Source # | |
Defined in GI.Gst.Objects.ParamArray | |
| BoxedPtr ParamArray Source # | |
Defined in GI.Gst.Objects.ParamArray | |
| ManagedPtrNewtype ParamArray Source # | |
Defined in GI.Gst.Objects.ParamArray Methods toManagedPtr :: ParamArray -> ManagedPtr ParamArray | |
| TypedObject ParamArray Source # | |
Defined in GI.Gst.Objects.ParamArray Methods glibType :: IO GType | |
| HasParentTypes ParamArray Source # | |
Defined in GI.Gst.Objects.ParamArray | |
| type ParentTypes ParamArray Source # | |
Defined in GI.Gst.Objects.ParamArray type ParentTypes ParamArray = '[ParamSpec] | |
class (BoxedPtr o, TypedObject o, IsDescendantOf ParamArray o) => IsParamArray o Source #
Type class for types which can be safely cast to ParamArray, for instance with toParamArray.
Instances
| (BoxedPtr o, TypedObject o, IsDescendantOf ParamArray o) => IsParamArray o Source # | |
Defined in GI.Gst.Objects.ParamArray | |
toParamArray :: (MonadIO m, IsParamArray o) => o -> m ParamArray Source #
Cast to ParamArray, for types for which this is known to be safe. For general casts, use castTo.