gi-gst-1.0.7: GStreamer bindings

CopyrightWill Thompson, Iñaki García Etxebarria and Jonas Platte
LicenseLGPL-2.1
MaintainerIñaki García Etxebarria (garetxe@gmail.com)
Safe HaskellNone
LanguageHaskell2010

GI.Gst.Structs.PluginDesc

Contents

Description

A plugin should export a variable of this type called plugin_desc. The plugin loader will use the data provided there to initialize the plugin.

The @licence parameter must be one of: LGPL, GPL, QPL, GPL/QPL, MPL, BSD, MIT/X11, Proprietary, unknown.

Synopsis

Exported types

newtype PluginDesc Source #

Constructors

PluginDesc (ManagedPtr PluginDesc) 

Instances

WrappedPtr PluginDesc Source # 
(~) AttrOpTag tag AttrSet => Constructible PluginDesc tag Source # 

Methods

new :: MonadIO m => (ManagedPtr PluginDesc -> PluginDesc) -> [AttrOp PluginDesc tag] -> m PluginDesc

((~) * info (ResolvePluginDescMethod t PluginDesc), MethodInfo * info PluginDesc p) => IsLabel t (PluginDesc -> p) Source # 

Methods

fromLabel :: Proxy# Symbol t -> PluginDesc -> p #

((~) * info (ResolvePluginDescMethod t PluginDesc), MethodInfo * info PluginDesc p) => IsLabelProxy t (PluginDesc -> p) Source # 
HasAttributeList * PluginDesc Source # 
type AttributeList PluginDesc Source # 
type AttributeList PluginDesc

newZeroPluginDesc :: MonadIO m => m PluginDesc Source #

Construct a PluginDesc struct initialized to zero.

Properties

description

pluginDesc_description :: AttrLabelProxy "description" Source #

license

pluginDesc_license :: AttrLabelProxy "license" Source #

majorVersion

pluginDesc_majorVersion :: AttrLabelProxy "majorVersion" Source #

minorVersion

pluginDesc_minorVersion :: AttrLabelProxy "minorVersion" Source #

name

pluginDesc_name :: AttrLabelProxy "name" Source #

origin

pluginDesc_origin :: AttrLabelProxy "origin" Source #

package

pluginDesc_package :: AttrLabelProxy "package" Source #

pluginInit

pluginDesc_pluginInit :: AttrLabelProxy "pluginInit" Source #

releaseDatetime

pluginDesc_releaseDatetime :: AttrLabelProxy "releaseDatetime" Source #

source

pluginDesc_source :: AttrLabelProxy "source" Source #

version

pluginDesc_version :: AttrLabelProxy "version" Source #